@@ -1,5 +1,5 @@
 /*  SMTUBE2, a small YouTube browser for SMPlayer
-    Copyright (C) 2015-2018 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2015-2019 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -72,6 +72,7 @@ protected slots:
 
 	void openWith(int player_id, const QUrl & url);
 	void openWith(const QString & player, const QUrl & url);
+	void openWithBrowser(const QUrl & url);
 
 	void openYTUrl(QString title, QString extension, const QString & url);
 	void openYTUrl(const QString & url, int itag);
@@ -101,7 +102,11 @@ protected:
 	void setStyle(QString style);
 #endif
 
+	void fetchVideoUrl(RetrieveYoutubeUrl * ry, const QUrl & url, int player_id = Undefined);
+
 private:
+	enum PlayerId { Undefined = -1, WebBrowser = -2 };
+
 	MyWebView *view;
 
 	QToolBar *toolbar;
@@ -114,13 +119,13 @@ private:
 
 	QSettings * settings;
 
-	int preferred_quality;
+	int preferred_resolution;
 	bool use_cookies;
 
 #ifdef USE_PLAYERS
 	Players players;
-	int current_player;
 #endif
+	int current_player;
 
 #ifdef D_BUTTON
 	bool add_download_button;
