@@ -1,5 +1,5 @@
 /*  SMTUBE2, a small YouTube browser for SMPlayer
-    Copyright (C) 2015-2018 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2015-2019 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -48,11 +48,13 @@ public:
 signals:
 	void requestedOpenWith(const QString &, const QUrl &);
 	void requestedOpenAudioWith(const QString &, const QUrl &);
+	void requestedOpenWithBrowser(const QUrl &);
 
 protected slots:
 	void openLinkInExternalBrowser();
 	void openWithTriggered();
 	void openAudioWithTriggered();
+	void openWithBrowserTriggered();
 
 protected:
 	void createContextMenu(int site_id, const QUrl & url);
@@ -67,6 +69,7 @@ private:
 
 #ifdef USE_PLAYERS
 	QList<Player> player_list;
+	QMenu * video_menu;
 	QMenu * audio_menu;
 #else
 	QString player_name;
